@@ -16,6 +16,7 @@ import unittest
 
 from muranoclient.tests.functional.cli import \
     murano_test_utils as utils
+from oslo_utils.strutils import bool_from_string as str2bool
 
 
 class SimpleReadOnlyMuranoClientTest(utils.CLIUtilsTestBase):
@@ -42,17 +43,20 @@ class SimpleReadOnlyMuranoClientTest(utils.CLIUtilsTestBase):
     def test_package_list(self):
         packages = self.get_table_struct('package-list')
         self.assertEqual(['ID', 'Name', 'FQN', 'Author', 'Active',
-                          'Is Public', 'Type'], packages)
+                          'Is Public', 'Type', 'Version'], packages)
 
 
 class TableStructureMuranoClientTest(utils.CLIUtilsTestBase):
-    """Smoke test for the Murano CLI commands which checks table
+    """Smoke test for the Murano CLI commands
+
+    Smoke test for the Murano CLI commands which checks table
     structure after create or delete category, env-template
     environment and package.
     """
 
     def test_table_struct_deployment_list(self):
         """Test scenario:
+
             1) create environment
             2) check table structure
         """
@@ -65,6 +69,7 @@ class TableStructureMuranoClientTest(utils.CLIUtilsTestBase):
 
     def test_table_struct_of_environment_create(self):
         """Test scenario:
+
             1) create environment
             2) check table structure
         """
@@ -75,6 +80,7 @@ class TableStructureMuranoClientTest(utils.CLIUtilsTestBase):
 
     def test_table_struct_of_environment_delete(self):
         """Test scenario:
+
             1) create environment
             2) delete environment
             3) check table structure
@@ -88,6 +94,7 @@ class TableStructureMuranoClientTest(utils.CLIUtilsTestBase):
 
     def test_table_struct_of_category_create(self):
         """Test scenario:
+
             1) create category
             2) check table structure
         """
@@ -97,6 +104,7 @@ class TableStructureMuranoClientTest(utils.CLIUtilsTestBase):
 
     def test_table_struct_of_category_delete(self):
         """Test scenario:
+
             1) create category
             2) delete category
             3) check table structure
@@ -109,6 +117,7 @@ class TableStructureMuranoClientTest(utils.CLIUtilsTestBase):
 
     def test_table_struct_of_env_template_create(self):
         """Test scenario:
+
             1) create env_template
             2) check table structure
         """
@@ -120,6 +129,7 @@ class TableStructureMuranoClientTest(utils.CLIUtilsTestBase):
 
     def test_table_struct_of_env_template_delete(self):
         """Test scenario:
+
             1) create env_template
             2) delete env_template
             3) check table structure
@@ -141,6 +151,7 @@ class EnvironmentMuranoSanityClientTest(utils.CLIUtilsTestBase):
 
     def test_environment_create(self):
         """Test scenario:
+
             1) create environment
             2) check that created environment exist
         """
@@ -152,6 +163,7 @@ class EnvironmentMuranoSanityClientTest(utils.CLIUtilsTestBase):
 
     def test_environment_delete(self):
         """Test scenario:
+
             1) create environment
             2) delete environment
         """
@@ -164,6 +176,7 @@ class EnvironmentMuranoSanityClientTest(utils.CLIUtilsTestBase):
 
     def test_environment_rename(self):
         """Test scenario:
+
             1) create environment
             2) rename environment
         """
@@ -182,6 +195,7 @@ class EnvironmentMuranoSanityClientTest(utils.CLIUtilsTestBase):
 
     def test_table_struct_env_show(self):
         """Test scenario:
+
             1) create environment
             2) check structure of env_show object
         """
@@ -189,12 +203,14 @@ class EnvironmentMuranoSanityClientTest(utils.CLIUtilsTestBase):
                                                 'TestMuranoSanityEnv')
         env_show = self.listing('environment-show', params=environment['Name'])
         # Check structure of env_show object
-        self.assertEqual(['acquired_by', 'created', 'id', 'name', 'services',
-                          'status', 'tenant_id', 'updated', 'version'],
+        self.assertEqual(['acquired_by', 'created', 'description_text', 'id',
+                          'name', 'services', 'status', 'tenant_id',
+                          'updated', 'version'],
                          map(lambda x: x['Property'], env_show))
 
     def test_environment_show(self):
         """Test scenario:
+
             1) create environment
             2) check that env_name, ID, updated and created values
                exist in env_show object
@@ -210,6 +226,20 @@ class EnvironmentMuranoSanityClientTest(utils.CLIUtilsTestBase):
         self.assertIn(environment['Name'], map(lambda x: x['Value'], env_show))
         self.assertIn(environment['ID'], map(lambda x: x['Value'], env_show))
 
+    def test_environment_delete_by_id(self):
+        """Test scenario:
+
+            1) create environment
+            2) delete environment by environment ID
+        """
+        env_name = self.generate_name('TestMuranoSanityEnv')
+        environment = self.create_murano_object('environment', env_name)
+        result = self.murano('environment-delete', params=environment['ID'],
+                             fail_ok=False)
+        self.assertNotIn(environment['Name'], result)
+        env_list = self.listing('environment-list')
+        self.assertNotIn(environment, env_list)
+
 
 class CategoryMuranoSanityClientTest(utils.CLIUtilsTestBase):
     """Sanity tests for testing actions with Category.
@@ -220,6 +250,7 @@ class CategoryMuranoSanityClientTest(utils.CLIUtilsTestBase):
 
     def test_category_create(self):
         """Test scenario:
+
             1) create category
             2) check that created category exist
         """
@@ -231,6 +262,7 @@ class CategoryMuranoSanityClientTest(utils.CLIUtilsTestBase):
 
     def test_category_delete(self):
         """Test scenario:
+
             1) create category
             2) delete category
             3) check that category has been deleted successfully
@@ -244,6 +276,7 @@ class CategoryMuranoSanityClientTest(utils.CLIUtilsTestBase):
 
     def test_table_struct_category_show(self):
         """Test scenario:
+
             1) create category
             2) check table structure of category-show object
         """
@@ -256,6 +289,7 @@ class CategoryMuranoSanityClientTest(utils.CLIUtilsTestBase):
 
     def test_category_show(self):
         """Test scenario:
+
             1) create category
             2) check that category values exist in category_show object
         """
@@ -269,6 +303,7 @@ class CategoryMuranoSanityClientTest(utils.CLIUtilsTestBase):
 
     def test_non_existing_category_delete(self):
         """Test scenario:
+
             1) try to call category-delete for non existing category
             2) check that error message contains user friendly substring
         """
@@ -279,6 +314,7 @@ class CategoryMuranoSanityClientTest(utils.CLIUtilsTestBase):
 
     def test_non_existing_category_show(self):
         """Test scenario:
+
             1) try to call category-show for non existing category
             2) check that error message contains user friendly substring
         """
@@ -288,13 +324,14 @@ class CategoryMuranoSanityClientTest(utils.CLIUtilsTestBase):
 
     def test_category_create_with_long_name(self):
         """Test scenario:
+
             1) try to create category with long name (>80)
             2) check that error message contains user friendly substring
         """
         result = self.murano('category-create', params='name' * 21,
                              fail_ok=True)
         self.assertIn(
-            "Category name should be 80 characters maximum (HTTP 400)",
+            "Category name should be 80 characters maximum",
             result)
 
 
@@ -306,6 +343,7 @@ class EnvTemplateMuranoSanityClientTest(utils.CLIUtilsTestBase):
     """
     def test_environment_template_create(self):
         """Test scenario:
+
             1) create environment template
             2) check that created environment template exist
         """
@@ -317,6 +355,7 @@ class EnvTemplateMuranoSanityClientTest(utils.CLIUtilsTestBase):
 
     def test_environment_template_delete(self):
         """Test scenario:
+
             1) create environment template
             2) delete environment template
             3) check that deleted environment template doesn't exist
@@ -330,6 +369,7 @@ class EnvTemplateMuranoSanityClientTest(utils.CLIUtilsTestBase):
 
     def test_table_struct_env_template_show(self):
         """Test scenario:
+
             1) create environment template
             2) check table structure of env-template-show object
         """
@@ -349,6 +389,7 @@ class EnvTemplateMuranoSanityClientTest(utils.CLIUtilsTestBase):
 
     def test_env_template_show(self):
         """Test scenario:
+
             1) create environment template
             2) check that environment template values exist in
             env-template-show object
@@ -366,6 +407,7 @@ class EnvTemplateMuranoSanityClientTest(utils.CLIUtilsTestBase):
 
     def test_env_template_create_environment(self):
         """Test scenario:
+
             1) create environment template
             2) create environment from template
         """
@@ -381,6 +423,7 @@ class EnvTemplateMuranoSanityClientTest(utils.CLIUtilsTestBase):
 
     def test_env_template_clone(self):
         """Test scenario:
+
             1) create environment template
             2) clone template
             3) check that create environment template has the new name
@@ -410,6 +453,7 @@ class PackageMuranoSanityClientTest(utils.CLIUtilsTestPackagesBase):
 
     def test_package_import_by_url(self):
         """Test scenario:
+
             1) import package by url
             2) check that package exists
         """
@@ -427,6 +471,7 @@ class PackageMuranoSanityClientTest(utils.CLIUtilsTestPackagesBase):
 
     def test_package_import_by_path(self):
         """Test scenario:
+
             1) import package by path
             2) check that package exists
         """
@@ -440,18 +485,27 @@ class PackageMuranoSanityClientTest(utils.CLIUtilsTestPackagesBase):
 
     def test_package_is_public(self):
         """Test scenario:
+
             1) import package
             2) check that package is public
         """
         package = self.import_package(
             self.app_name,
             self.dummy_app_path,
-            '--is-public'
-        )
+            '--is-public')
+
+        package_show = self.listing('package-show', params=package['ID'])
+        package_show = {item['Property']: item['Value']
+                        for item in package_show}
+
         self.assertEqual(package['Is Public'], 'True')
+        self.assertEqual(
+            str2bool(package['Is Public']),
+            str2bool(package_show['is_public']))
 
     def test_package_delete(self):
         """Test scenario:
+
             1) import package
             2) delete package
             3) check that package has been deleted
@@ -467,6 +521,7 @@ class PackageMuranoSanityClientTest(utils.CLIUtilsTestPackagesBase):
 
     def test_package_show(self):
         """Test scenario:
+
             1) import package
             2) check that package values exist in
             return by package-show object
@@ -477,16 +532,31 @@ class PackageMuranoSanityClientTest(utils.CLIUtilsTestPackagesBase):
             self.dummy_app_path
         )
         package_show = self.listing('package-show', params=package['ID'])
+        package_show = {item['Property']: item['Value']
+                        for item in package_show}
 
-        tested_package = map(lambda x: x['Value'], package_show)
-
-        self.assertIn(package['ID'], tested_package)
-        self.assertIn(package['Name'], tested_package)
-        self.assertIn(package['FQN'], tested_package)
-        self.assertIn(package['Is Public'], tested_package)
+        self.assertEqual(
+            str2bool(package['Active']),
+            str2bool(package_show['enabled']))
+        self.assertEqual(
+            package['FQN'],
+            package_show['fully_qualified_name'])
+        self.assertEqual(
+            package['ID'],
+            package_show['id'])
+        self.assertEqual(
+            str2bool(package['Is Public']),
+            str2bool(package_show['is_public']))
+        self.assertEqual(
+            package['Name'],
+            package_show['name'])
+        self.assertEqual(
+            package['Type'],
+            package_show['type'])
 
     def test_package_import_update(self):
         """Test scenario:
+
             1) import package
             2) import new_package using option 'u' - update
             3) check that package has been updated
@@ -505,6 +575,7 @@ class PackageMuranoSanityClientTest(utils.CLIUtilsTestPackagesBase):
 
     def test_package_import_skip(self):
         """Test scenario:
+
             1) import package using option 's' - skip for existing package
             2) try to import the same package using option 's' - skip
             3) check that package hasn't been updated
@@ -526,6 +597,7 @@ class PackageMuranoSanityClientTest(utils.CLIUtilsTestPackagesBase):
 
     def test_package_import_abort(self):
         """Test scenario:
+
             1) import package
             2) import new_package using option 'a' - skip
             3) check that package hasn't been updated
@@ -557,6 +629,7 @@ class DeployMuranoEnvironmentTest(utils.CLIUtilsTestPackagesBase):
 
     def test_environment_deployment(self):
         """Test scenario:
+
             1) import package
             2) create environment
             3) create session for created environment
@@ -589,6 +662,7 @@ class DeployMuranoEnvironmentTest(utils.CLIUtilsTestPackagesBase):
 
     def test_add_component_to_deployed_env(self):
         """Test scenario:
+
             1) import package
             2) create environment
             3) create session for created environment
@@ -634,6 +708,7 @@ class DeployMuranoEnvironmentTest(utils.CLIUtilsTestPackagesBase):
     @unittest.expectedFailure
     def test_delete_component_from_deployed_env(self):
         """Test scenario:
+
             1) import package
             2) create environment
             3) create session for created environment
@@ -683,9 +758,80 @@ class BundleMuranoSanityClientTest(utils.CLIUtilsTestPackagesBase):
 
     def test_bundle_import_without_bundle_name(self):
         """Test scenario:
+
             1) Execute murano bundle-import command without bundle name
             2) check that error message contains user friendly substring
         """
         result = self.murano('bundle-import', params='',
                              fail_ok=True)
         self.assertIn("murano bundle-import: error: too few arguments", result)
+
+    def test_bundle_import_with_non_existing_package_name(self):
+        """Test scenario:
+
+            1) Execute murano bundle-import command with non-existing packages
+            name inside
+            2) check that error message contains user friendly substring
+        """
+        result = self.murano(
+            'bundle-import',
+            params=self.prepare_bundle_with_non_existed_package(),
+            fail_ok=False)
+        self.assertIn("Couldn't find file for package", result)
+        self.assertIn("Error Got non-ok status(404) while connecting", result)
+
+    def test_bundle_import_with_non_existing_name(self):
+        """Test scenario:
+
+            1) Execute murano bundle-import command with non-existing bundle
+            name
+            2) check that error message contains user friendly substring
+        """
+        result = self.murano('bundle-import', params=self.app_name,
+                             fail_ok=True)
+        self.assertIn("Bundle file '{}' does not exist".format(self.app_name),
+                      result)
+        self.assertIn("reason: Got non-ok status(404) while connecting to",
+                      result)
+
+    def test_bundle_import_with_invalid_file_format(self):
+        """Test scenario:
+
+            1) Execute murano bundle-import command with invalid bundle file
+            format
+            2) check that error message contains user friendly substring
+        """
+        try:
+            self.murano(
+                'bundle-import',
+                params=self.prepare_bundle_with_invalid_format(),
+                fail_ok=False)
+        except utils.exceptions.CommandFailed as exception:
+            self.assertIn("Can't parse bundle contents", exception.stdout)
+
+
+class StaticActionMuranoClientTest(utils.CLIUtilsTestPackagesBase):
+    """Tests for testing static actions execution.
+
+    Tests for the Murano CLI commands which check the result of sample
+    static action execution.
+    """
+
+    def test_static_action_call(self):
+        """Test scenario:
+
+                1) import package
+                2) call static action of the class in that package
+                3) check the result of action
+        """
+        package = self.import_package(
+            self.app_name,
+            self.dummy_app_path
+        )
+        result = self.murano(
+            'static-action-call', params='{0} staticAction --package-name {1} '
+            '--arguments myName=John myAge=28'.format(package['FQN'],
+                                                      package['FQN']))
+        expected = "Waiting for result...\nStatic action result: Hello, " \
+                   "John. In 5 years you will be 33 years old.\n"
+        self.assertEqual(expected, result)
